ScreenPy
========
```
TITLE CARD:
                                "ScreenPy PyOTP"
TITLE DISAPPEARS.
                                                                      FADE IN:
EXT. DOCUMENTATION - MIDNIGHT

AUDIENCE continues walking, guided by the mysterious voice of the NARRATOR.
AUDIENCE winds through a garden of large hedges, twisting past brambles,
until they arrive at a single large, glowing lock upon a pedestal.


                              NARRATOR (V.O.)
            ... and you have arrived at ScreenPy PyOTP, an
            extension which enables using One Time Passwords.

                              AUDIENCE
            Wait, how long has it been since I met you? How is this
            pedestal glowing like that? And what, there's only one
            tchotchke this time?

                              NARRATOR (V.O.)
            Extensions do not need to be all that large to enable
            great things. This library provides only the Ability
            an Actor needs for two-factor authentication.

                              AUDIENCE
            You always seem to ignore the questions I most want the
            answers to.

                              NARRATOR (V.O.)
            Continuing along, to your left...

                                                                      FADE OUT
```


Installation
------------
    pip install screenpy_pyotp

or

    pip install screenpy[pyotp]


Documentation
----------
Please check out the [Read The Docs documentation](https://screenpy-pyotp-docs.readthedocs.io/en/latest/) for the latest information about this module!

You can also read the [ScreenPy Docs](https://screenpy-docs.readthedocs.io/en/latest/) for more information about ScreenPy in general.


Contributing
------------
You want to contribute? Great! Here are the things you should do before submitting your PR:

1. Install [`pre-commit`](https://pre-commit.com/)
1. run `pre-commit install` once.
1. run `tox` to perform tests frequently.

That's it! :)
